# This file was automatically generated by SWIG (http://www.swig.org).
# Version 1.3.33
#
# Don't modify this file, modify the SWIG interface instead.

package WSO2::WSF::C;
require Exporter;
require DynaLoader;
@ISA = qw(Exporter DynaLoader);
package WSO2::WSF::Cc;
bootstrap WSO2::WSF::C;
package WSO2::WSF::C;
@EXPORT = qw( );

# ---------- BASE METHODS -------------

package WSO2::WSF::C;

sub TIEHASH {
    my ($classname,$obj) = @_;
    return bless $obj, $classname;
}

sub CLEAR { }

sub FIRSTKEY { }

sub NEXTKEY { }

sub FETCH {
    my ($self,$field) = @_;
    my $member_func = "swig_${field}_get";
    $self->$member_func();
}

sub STORE {
    my ($self,$field,$newval) = @_;
    my $member_func = "swig_${field}_set";
    $self->$member_func($newval);
}

sub this {
    my $ptr = shift;
    return tied(%$ptr);
}


# ------- FUNCTION WRAPPERS --------

package WSO2::WSF::C;

*wsf_axiom_data_handler_get_content = *WSO2::WSF::Cc::wsf_axiom_data_handler_get_content;
*wsf_client_set_module_param_option = *WSO2::WSF::Cc::wsf_client_set_module_param_option;
*axiom_xml_reader_create_for_memory_new = *WSO2::WSF::Cc::axiom_xml_reader_create_for_memory_new;
*wsf_axiom_element_get_first_node = *WSO2::WSF::Cc::wsf_axiom_element_get_first_node;
*wsf_get_last_soap_fault_base_node = *WSO2::WSF::Cc::wsf_get_last_soap_fault_base_node;
*set_ssl_settings = *WSO2::WSF::Cc::set_ssl_settings;
*wsf_last_soap_fault_exception = *WSO2::WSF::Cc::wsf_last_soap_fault_exception;
*wsf_set_module_param_value = *WSO2::WSF::Cc::wsf_set_module_param_value;
*wsf_axiom_node_get_data_element = *WSO2::WSF::Cc::wsf_axiom_node_get_data_element;
*wsf_axiom_node_get_text_element = *WSO2::WSF::Cc::wsf_axiom_node_get_text_element;
*wsf_axiom_attach_content = *WSO2::WSF::Cc::wsf_axiom_attach_content;
*wsf_str_to_axiom_node = *WSO2::WSF::Cc::wsf_str_to_axiom_node;
*wsf_axiom_node_to_str = *WSO2::WSF::Cc::wsf_axiom_node_to_str;
*wsf_axutil_property_create_with_args = *WSO2::WSF::Cc::wsf_axutil_property_create_with_args;
*wsf_axutil_property_set_value = *WSO2::WSF::Cc::wsf_axutil_property_set_value;
*wsf_axutil_strcmp = *WSO2::WSF::Cc::wsf_axutil_strcmp;
*wsf_axis2_options_set_property = *WSO2::WSF::Cc::wsf_axis2_options_set_property;
*wsf_axutil_strdup = *WSO2::WSF::Cc::wsf_axutil_strdup;
*axis2_log_debug = *WSO2::WSF::Cc::axis2_log_debug;
*axis2_log_critical = *WSO2::WSF::Cc::axis2_log_critical;
*axis2_log_error = *WSO2::WSF::Cc::axis2_log_error;
*wsf_rampart_context_set_receiver_certificate = *WSO2::WSF::Cc::wsf_rampart_context_set_receiver_certificate;
*wsf_rampart_context_set_prv_key = *WSO2::WSF::Cc::wsf_rampart_context_set_prv_key;
*wsf_rampart_context_set_certificate = *WSO2::WSF::Cc::wsf_rampart_context_set_certificate;
*wsf_util_find_xop_content_and_convert_to_base64 = *WSO2::WSF::Cc::wsf_util_find_xop_content_and_convert_to_base64;
*wsf_set_security_data_to_rampart_context = *WSO2::WSF::Cc::wsf_set_security_data_to_rampart_context;
*handle_client_security = *WSO2::WSF::Cc::handle_client_security;
*new_axiom_node_t_pp = *WSO2::WSF::Cc::new_axiom_node_t_pp;
*copy_axiom_node_t_pp = *WSO2::WSF::Cc::copy_axiom_node_t_pp;
*delete_axiom_node_t_pp = *WSO2::WSF::Cc::delete_axiom_node_t_pp;
*axiom_node_t_pp_assign = *WSO2::WSF::Cc::axiom_node_t_pp_assign;
*axiom_node_t_pp_value = *WSO2::WSF::Cc::axiom_node_t_pp_value;
*axutil_env_create_all = *WSO2::WSF::Cc::axutil_env_create_all;
*axis2_endpoint_ref_create = *WSO2::WSF::Cc::axis2_endpoint_ref_create;
*axis2_options_set_to = *WSO2::WSF::Cc::axis2_options_set_to;
*axis2_options_set_from = *WSO2::WSF::Cc::axis2_options_set_from;
*axis2_options_set_action = *WSO2::WSF::Cc::axis2_options_set_action;
*axis2_options_set_enable_rest = *WSO2::WSF::Cc::axis2_options_set_enable_rest;
*axis2_options_set_http_method = *WSO2::WSF::Cc::axis2_options_set_http_method;
*axis2_options_set_soap_version = *WSO2::WSF::Cc::axis2_options_set_soap_version;
*axis2_options_set_soap_action = *WSO2::WSF::Cc::axis2_options_set_soap_action;
*axis2_options_set_reply_to = *WSO2::WSF::Cc::axis2_options_set_reply_to;
*axis2_options_set_fault_to = *WSO2::WSF::Cc::axis2_options_set_fault_to;
*axis2_options_set_enable_mtom = *WSO2::WSF::Cc::axis2_options_set_enable_mtom;
*axis2_svc_client_create = *WSO2::WSF::Cc::axis2_svc_client_create;
*axis2_svc_client_engage_module = *WSO2::WSF::Cc::axis2_svc_client_engage_module;
*axiom_node_to_string = *WSO2::WSF::Cc::axiom_node_to_string;
*axiom_node_get_node_type = *WSO2::WSF::Cc::axiom_node_get_node_type;
*axiom_node_get_first_child = *WSO2::WSF::Cc::axiom_node_get_first_child;
*axiom_node_get_next_sibling = *WSO2::WSF::Cc::axiom_node_get_next_sibling;
*axiom_node_get_first_element = *WSO2::WSF::Cc::axiom_node_get_first_element;
*axiom_element_get_text = *WSO2::WSF::Cc::axiom_element_get_text;
*axiom_element_get_child_elements = *WSO2::WSF::Cc::axiom_element_get_child_elements;
*axiom_child_element_iterator_next = *WSO2::WSF::Cc::axiom_child_element_iterator_next;
*axiom_element_get_localname = *WSO2::WSF::Cc::axiom_element_get_localname;
*axiom_element_get_namespace = *WSO2::WSF::Cc::axiom_element_get_namespace;
*axiom_namespace_get_uri = *WSO2::WSF::Cc::axiom_namespace_get_uri;
*axiom_element_get_attribute_value_by_name = *WSO2::WSF::Cc::axiom_element_get_attribute_value_by_name;
*axiom_node_detach = *WSO2::WSF::Cc::axiom_node_detach;
*axiom_data_handler_create = *WSO2::WSF::Cc::axiom_data_handler_create;
*axiom_text_get_data_handler = *WSO2::WSF::Cc::axiom_text_get_data_handler;
*axiom_data_handler_get_content_type = *WSO2::WSF::Cc::axiom_data_handler_get_content_type;
*axiom_text_get_content_id = *WSO2::WSF::Cc::axiom_text_get_content_id;
*axis2_svc_client_send_receive = *WSO2::WSF::Cc::axis2_svc_client_send_receive;
*axis2_svc_client_send_robust = *WSO2::WSF::Cc::axis2_svc_client_send_robust;
*axis2_svc_client_get_options = *WSO2::WSF::Cc::axis2_svc_client_get_options;
*axis2_options_create = *WSO2::WSF::Cc::axis2_options_create;
*axis2_svc_client_set_options = *WSO2::WSF::Cc::axis2_svc_client_set_options;
*axiom_xml_reader_free = *WSO2::WSF::Cc::axiom_xml_reader_free;
*axis2_svc_client_set_proxy = *WSO2::WSF::Cc::axis2_svc_client_set_proxy;
*axutil_property_create = *WSO2::WSF::Cc::axutil_property_create;
*axutil_string_create = *WSO2::WSF::Cc::axutil_string_create;
*axutil_uuid_gen = *WSO2::WSF::Cc::axutil_uuid_gen;
*axis2_svc_client_get_last_response_has_fault = *WSO2::WSF::Cc::axis2_svc_client_get_last_response_has_fault;
*axis2_options_set_xml_parser_reset = *WSO2::WSF::Cc::axis2_options_set_xml_parser_reset;
*axis2_conf_add_param = *WSO2::WSF::Cc::axis2_conf_add_param;
*axutil_param_create = *WSO2::WSF::Cc::axutil_param_create;
*axis2_svc_client_get_svc = *WSO2::WSF::Cc::axis2_svc_client_get_svc;
*axis2_svc_get_base = *WSO2::WSF::Cc::axis2_svc_get_base;
*axis2_svc_client_get_svc_ctx = *WSO2::WSF::Cc::axis2_svc_client_get_svc_ctx;
*axis2_svc_ctx_get_conf_ctx = *WSO2::WSF::Cc::axis2_svc_ctx_get_conf_ctx;
*axis2_conf_ctx_get_conf = *WSO2::WSF::Cc::axis2_conf_ctx_get_conf;
*axis2_desc_get_policy_include = *WSO2::WSF::Cc::axis2_desc_get_policy_include;
*axis2_policy_include_add_policy_element = *WSO2::WSF::Cc::axis2_policy_include_add_policy_element;
*neethi_options_create = *WSO2::WSF::Cc::neethi_options_create;
*neethi_options_set_include_timestamp = *WSO2::WSF::Cc::neethi_options_set_include_timestamp;
*neethi_options_set_is_username_token = *WSO2::WSF::Cc::neethi_options_set_is_username_token;
*neethi_options_set_encrypt_body = *WSO2::WSF::Cc::neethi_options_set_encrypt_body;
*neethi_options_set_algorithmsuite = *WSO2::WSF::Cc::neethi_options_set_algorithmsuite;
*neethi_options_set_keyidentifier = *WSO2::WSF::Cc::neethi_options_set_keyidentifier;
*neethi_options_set_sign_body = *WSO2::WSF::Cc::neethi_options_set_sign_body;
*neethi_options_set_signature_protection = *WSO2::WSF::Cc::neethi_options_set_signature_protection;
*neethi_options_set_encrypt_before_sign = *WSO2::WSF::Cc::neethi_options_set_encrypt_before_sign;
*neethi_options_get_root_node = *WSO2::WSF::Cc::neethi_options_get_root_node;
*neethi_engine_get_policy = *WSO2::WSF::Cc::neethi_engine_get_policy;
*rampart_context_create = *WSO2::WSF::Cc::rampart_context_create;
*rampart_context_set_prv_key = *WSO2::WSF::Cc::rampart_context_set_prv_key;
*rampart_context_set_prv_key_type = *WSO2::WSF::Cc::rampart_context_set_prv_key_type;
*rampart_context_set_certificate = *WSO2::WSF::Cc::rampart_context_set_certificate;
*rampart_context_set_certificate_type = *WSO2::WSF::Cc::rampart_context_set_certificate_type;
*rampart_context_set_receiver_certificate = *WSO2::WSF::Cc::rampart_context_set_receiver_certificate;
*rampart_context_set_receiver_certificate_type = *WSO2::WSF::Cc::rampart_context_set_receiver_certificate_type;
*rampart_context_set_user = *WSO2::WSF::Cc::rampart_context_set_user;
*rampart_context_set_password = *WSO2::WSF::Cc::rampart_context_set_password;
*rampart_context_set_password_type = *WSO2::WSF::Cc::rampart_context_set_password_type;
*rampart_context_set_ttl = *WSO2::WSF::Cc::rampart_context_set_ttl;
*rampart_context_set_pwcb_function = *WSO2::WSF::Cc::rampart_context_set_pwcb_function;
*axiom_namespace_create = *WSO2::WSF::Cc::axiom_namespace_create;
*axiom_element_create = *WSO2::WSF::Cc::axiom_element_create;
*axiom_attribute_create = *WSO2::WSF::Cc::axiom_attribute_create;
*axiom_element_add_attribute = *WSO2::WSF::Cc::axiom_element_add_attribute;
*axiom_element_set_text = *WSO2::WSF::Cc::axiom_element_set_text;
*axis2_svc_client_add_header = *WSO2::WSF::Cc::axis2_svc_client_add_header;

############# Class : WSO2::WSF::C::fault_data_t ##############

package WSO2::WSF::C::fault_data_t;
use vars qw(@ISA %OWNER %ITERATORS %BLESSEDMEMBERS);
@ISA = qw( WSO2::WSF::C );
%OWNER = ();
%ITERATORS = ();
*swig_code_get = *WSO2::WSF::Cc::fault_data_t_code_get;
*swig_code_set = *WSO2::WSF::Cc::fault_data_t_code_set;
*swig_reason_get = *WSO2::WSF::Cc::fault_data_t_reason_get;
*swig_reason_set = *WSO2::WSF::Cc::fault_data_t_reason_set;
*swig_role_get = *WSO2::WSF::Cc::fault_data_t_role_get;
*swig_role_set = *WSO2::WSF::Cc::fault_data_t_role_set;
*swig_detail_get = *WSO2::WSF::Cc::fault_data_t_detail_get;
*swig_detail_set = *WSO2::WSF::Cc::fault_data_t_detail_set;
*swig_xml_get = *WSO2::WSF::Cc::fault_data_t_xml_get;
*swig_xml_set = *WSO2::WSF::Cc::fault_data_t_xml_set;
sub new {
    my $pkg = shift;
    my $self = WSO2::WSF::Cc::new_fault_data_t(@_);
    bless $self, $pkg if defined($self);
}

sub DESTROY {
    return unless $_[0]->isa('HASH');
    my $self = tied(%{$_[0]});
    return unless defined $self;
    delete $ITERATORS{$self};
    if (exists $OWNER{$self}) {
        WSO2::WSF::Cc::delete_fault_data_t($self);
        delete $OWNER{$self};
    }
}

sub DISOWN {
    my $self = shift;
    my $ptr = tied(%$self);
    delete $OWNER{$ptr};
}

sub ACQUIRE {
    my $self = shift;
    my $ptr = tied(%$self);
    $OWNER{$ptr} = 1;
}


# ------- VARIABLE STUBS --------

package WSO2::WSF::C;

*WSF_CP_SEC_TOKEN = *WSO2::WSF::Cc::WSF_CP_SEC_TOKEN;
*AXIS2_LOG_LEVEL_CRITICAL = *WSO2::WSF::Cc::AXIS2_LOG_LEVEL_CRITICAL;
*AXIS2_LOG_LEVEL_ERROR = *WSO2::WSF::Cc::AXIS2_LOG_LEVEL_ERROR;
*AXIS2_LOG_LEVEL_WARNING = *WSO2::WSF::Cc::AXIS2_LOG_LEVEL_WARNING;
*AXIS2_LOG_LEVEL_INFO = *WSO2::WSF::Cc::AXIS2_LOG_LEVEL_INFO;
*AXIS2_LOG_LEVEL_DEBUG = *WSO2::WSF::Cc::AXIS2_LOG_LEVEL_DEBUG;
*AXIS2_LOG_LEVEL_USER = *WSO2::WSF::Cc::AXIS2_LOG_LEVEL_USER;
*AXIS2_LOG_LEVEL_TRACE = *WSO2::WSF::Cc::AXIS2_LOG_LEVEL_TRACE;
*AXIS2_XML_PARSER_TYPE_BUFFER = *WSO2::WSF::Cc::AXIS2_XML_PARSER_TYPE_BUFFER;
*AXIS2_XML_PARSER_TYPE_FILE = *WSO2::WSF::Cc::AXIS2_XML_PARSER_TYPE_FILE;
*AXIS2_XML_PARSER_TYPE_DOC = *WSO2::WSF::Cc::AXIS2_XML_PARSER_TYPE_DOC;
*AXIOM_SOAP_VERSION_NOT_SET = *WSO2::WSF::Cc::AXIOM_SOAP_VERSION_NOT_SET;
*AXIOM_SOAP11 = *WSO2::WSF::Cc::AXIOM_SOAP11;
*AXIOM_SOAP12 = *WSO2::WSF::Cc::AXIOM_SOAP12;
*AXIS2_SCOPE_REQUEST = *WSO2::WSF::Cc::AXIS2_SCOPE_REQUEST;
*AXIS2_SCOPE_SESSION = *WSO2::WSF::Cc::AXIS2_SCOPE_SESSION;
*AXIS2_SCOPE_APPLICATION = *WSO2::WSF::Cc::AXIS2_SCOPE_APPLICATION;
*AXIOM_INVALID = *WSO2::WSF::Cc::AXIOM_INVALID;
*AXIOM_DOCUMENT = *WSO2::WSF::Cc::AXIOM_DOCUMENT;
*AXIOM_ELEMENT = *WSO2::WSF::Cc::AXIOM_ELEMENT;
*AXIOM_DOCTYPE = *WSO2::WSF::Cc::AXIOM_DOCTYPE;
*AXIOM_COMMENT = *WSO2::WSF::Cc::AXIOM_COMMENT;
*AXIOM_ATTRIBUTE = *WSO2::WSF::Cc::AXIOM_ATTRIBUTE;
*AXIOM_NAMESPACE = *WSO2::WSF::Cc::AXIOM_NAMESPACE;
*AXIOM_PROCESSING_INSTRUCTION = *WSO2::WSF::Cc::AXIOM_PROCESSING_INSTRUCTION;
*AXIOM_TEXT = *WSO2::WSF::Cc::AXIOM_TEXT;
*AXIOM_DATA_SOURCE = *WSO2::WSF::Cc::AXIOM_DATA_SOURCE;
*AXIS2_POLICY = *WSO2::WSF::Cc::AXIS2_POLICY;
*AXIS2_MODULE_POLICY = *WSO2::WSF::Cc::AXIS2_MODULE_POLICY;
*AXIS2_SERVICE_POLICY = *WSO2::WSF::Cc::AXIS2_SERVICE_POLICY;
*AXIS2_OPERATION_POLICY = *WSO2::WSF::Cc::AXIS2_OPERATION_POLICY;
*AXIS2_MESSAGE_POLICY = *WSO2::WSF::Cc::AXIS2_MESSAGE_POLICY;
*AXIS2_PORT_POLICY = *WSO2::WSF::Cc::AXIS2_PORT_POLICY;
*AXIS2_PORT_TYPE_POLICY = *WSO2::WSF::Cc::AXIS2_PORT_TYPE_POLICY;
*AXIS2_BINDING_POLICY = *WSO2::WSF::Cc::AXIS2_BINDING_POLICY;
*AXIS2_BINDING_OPERATION_POLICY = *WSO2::WSF::Cc::AXIS2_BINDING_OPERATION_POLICY;
*AXIS2_INPUT_POLICY = *WSO2::WSF::Cc::AXIS2_INPUT_POLICY;
*AXIS2_OUTPUT_POLICY = *WSO2::WSF::Cc::AXIS2_OUTPUT_POLICY;
*AXIS2_BINDING_INPUT_POLICY = *WSO2::WSF::Cc::AXIS2_BINDING_INPUT_POLICY;
*AXIS2_BINDING_OUTPUT_POLICY = *WSO2::WSF::Cc::AXIS2_BINDING_OUTPUT_POLICY;
*AXIS2_MODULE_OPERATION_POLICY = *WSO2::WSF::Cc::AXIS2_MODULE_OPERATION_POLICY;
*AXIS2_POLICY_REF = *WSO2::WSF::Cc::AXIS2_POLICY_REF;
*AXIS2_ANON_POLICY = *WSO2::WSF::Cc::AXIS2_ANON_POLICY;
*AXIS2_KEY_TYPE_UNKNOWN = *WSO2::WSF::Cc::AXIS2_KEY_TYPE_UNKNOWN;
*AXIS2_KEY_TYPE_PEM = *WSO2::WSF::Cc::AXIS2_KEY_TYPE_PEM;
*AXIS2_KEY_TYPE_DER = *WSO2::WSF::Cc::AXIS2_KEY_TYPE_DER;
*WSF_RM_DEFAULT_RESPONSE_TIMEOUT = *WSO2::WSF::Cc::WSF_RM_DEFAULT_RESPONSE_TIMEOUT;
*WSF_DEFAULT_WSF_HOME = *WSO2::WSF::Cc::WSF_DEFAULT_WSF_HOME;
*WSF_DEFAULT_LOG_FILE_NAME = *WSO2::WSF::Cc::WSF_DEFAULT_LOG_FILE_NAME;
*WSF_DEFAULT_CONTENT_TYPE = *WSO2::WSF::Cc::WSF_DEFAULT_CONTENT_TYPE;
*AXIS2_ELEMENT_LN_INCLUDE = *WSO2::WSF::Cc::AXIS2_ELEMENT_LN_INCLUDE;
*AXIS2_NAMESPACE_URI_INCLUDE = *WSO2::WSF::Cc::AXIS2_NAMESPACE_URI_INCLUDE;
*AXIS2_ELEMENT_ATTR_NAME_CONTENT_TYPE = *WSO2::WSF::Cc::AXIS2_ELEMENT_ATTR_NAME_CONTENT_TYPE;
*AXIS2_ELEMENT_ATTR_NAME_HREF = *WSO2::WSF::Cc::AXIS2_ELEMENT_ATTR_NAME_HREF;
*WSF_RM_VERSION_1_0_STR = *WSO2::WSF::Cc::WSF_RM_VERSION_1_0_STR;
*WSF_RM_VERSION_1_0 = *WSO2::WSF::Cc::WSF_RM_VERSION_1_0;
*WSF_RM_VERSION_1_1_STR = *WSO2::WSF::Cc::WSF_RM_VERSION_1_1_STR;
*WSF_RM_VERSION_1_1 = *WSO2::WSF::Cc::WSF_RM_VERSION_1_1;
*WSF_SANDESHA2_CLIENT_RM_SPEC_VERSION = *WSO2::WSF::Cc::WSF_SANDESHA2_CLIENT_RM_SPEC_VERSION;
*WSF_SANDESHA2_CLIENT_INACT_TIMEOUT = *WSO2::WSF::Cc::WSF_SANDESHA2_CLIENT_INACT_TIMEOUT;
*WSF_SANDESHA2_CLIENT_SEQ_KEY = *WSO2::WSF::Cc::WSF_SANDESHA2_CLIENT_SEQ_KEY;
*WSF_SANDESHA2_CLIENT_LAST_MESSAGE = *WSO2::WSF::Cc::WSF_SANDESHA2_CLIENT_LAST_MESSAGE;
*WSF_SANDESHA2_CLIENT_OFFERED_SEQ_ID = *WSO2::WSF::Cc::WSF_SANDESHA2_CLIENT_OFFERED_SEQ_ID;
*WSF_SANDESHA2_CLIENT_TIME_OUT = *WSO2::WSF::Cc::WSF_SANDESHA2_CLIENT_TIME_OUT;
*WSF_SANDESHA2_CLIENT_DEFAULT_TIME_OUT = *WSO2::WSF::Cc::WSF_SANDESHA2_CLIENT_DEFAULT_TIME_OUT;
*AXIS2_TIMEOUT_IN_SECONDS = *WSO2::WSF::Cc::AXIS2_TIMEOUT_IN_SECONDS;
*WSF_CP_PROXY_HOST = *WSO2::WSF::Cc::WSF_CP_PROXY_HOST;
*WSF_CP_PROXY_PORT = *WSO2::WSF::Cc::WSF_CP_PROXY_PORT;
*WSF_CP_USE_SOAP = *WSO2::WSF::Cc::WSF_CP_USE_SOAP;
*WSF_CP_HTTP_METHOD = *WSO2::WSF::Cc::WSF_CP_HTTP_METHOD;
*WSF_CP_CA_CERT = *WSO2::WSF::Cc::WSF_CP_CA_CERT;
*WSF_CP_CLIENT_CERT = *WSO2::WSF::Cc::WSF_CP_CLIENT_CERT;
*WSF_CP_PASS_PHRASE = *WSO2::WSF::Cc::WSF_CP_PASS_PHRASE;
*WSF_CP_USE_WSA = *WSO2::WSF::Cc::WSF_CP_USE_WSA;
*WSF_CP_USE_MTOM = *WSO2::WSF::Cc::WSF_CP_USE_MTOM;
*WSF_CP_POLICY = *WSO2::WSF::Cc::WSF_CP_POLICY;
*WSF_CP_WSDL = *WSO2::WSF::Cc::WSF_CP_WSDL;
*WSF_CP_RES_XOP = *WSO2::WSF::Cc::WSF_CP_RES_XOP;
*WSF_CP_RELIABLE = *WSO2::WSF::Cc::WSF_CP_RELIABLE;
*WSF_CP_SEQ_EXP_TIME = *WSO2::WSF::Cc::WSF_CP_SEQ_EXP_TIME;
*WSF_CP_SEQ_KEY = *WSO2::WSF::Cc::WSF_CP_SEQ_KEY;
*WSF_CP_WILL_CON_SEQ = *WSO2::WSF::Cc::WSF_CP_WILL_CON_SEQ;
*WSF_CP_RES_TIME_OUT = *WSO2::WSF::Cc::WSF_CP_RES_TIME_OUT;
*WSF_MP_TO = *WSO2::WSF::Cc::WSF_MP_TO;
*WSF_MP_ACTION = *WSO2::WSF::Cc::WSF_MP_ACTION;
*WSF_MP_FROM = *WSO2::WSF::Cc::WSF_MP_FROM;
*WSF_MP_REPLY_TO = *WSO2::WSF::Cc::WSF_MP_REPLY_TO;
*WSF_MP_FAULT_TO = *WSO2::WSF::Cc::WSF_MP_FAULT_TO;
*WSF_MP_ATTACHMENTS = *WSO2::WSF::Cc::WSF_MP_ATTACHMENTS;
*WSF_MP_DEF_ATT_CON_TYPE = *WSO2::WSF::Cc::WSF_MP_DEF_ATT_CON_TYPE;
*WSF_MP_LAST_MSG = *WSO2::WSF::Cc::WSF_MP_LAST_MSG;
*WSF_PROP_NAME_SERVER_CERT = *WSO2::WSF::Cc::WSF_PROP_NAME_SERVER_CERT;
*WSF_PROP_NAME_KEY_FILE = *WSO2::WSF::Cc::WSF_PROP_NAME_KEY_FILE;
*WSF_PROP_NAME_SSL_PASSPHRASE = *WSO2::WSF::Cc::WSF_PROP_NAME_SSL_PASSPHRASE;
*WSF_SEC_TOK_OPT_PRIVATE_KEY = *WSO2::WSF::Cc::WSF_SEC_TOK_OPT_PRIVATE_KEY;
*WSF_SEC_TOK_OPT_CERT = *WSO2::WSF::Cc::WSF_SEC_TOK_OPT_CERT;
*WSF_SEC_TOK_OPT_REC_CERT = *WSO2::WSF::Cc::WSF_SEC_TOK_OPT_REC_CERT;
*WSF_SEC_TOK_OPT_USER = *WSO2::WSF::Cc::WSF_SEC_TOK_OPT_USER;
*WSF_SEC_TOK_OPT_PWD = *WSO2::WSF::Cc::WSF_SEC_TOK_OPT_PWD;
*WSF_SEC_TOK_OPT_PWD_TYPE = *WSO2::WSF::Cc::WSF_SEC_TOK_OPT_PWD_TYPE;
*WSF_SEC_TOK_OPT_TTL = *WSO2::WSF::Cc::WSF_SEC_TOK_OPT_TTL;
*WSF_CONF_LOG_DIR = *WSO2::WSF::Cc::WSF_CONF_LOG_DIR;
*WSF_CONF_LOG_LEVEL = *WSO2::WSF::Cc::WSF_CONF_LOG_LEVEL;
*WSF_CONF_WSFC_HOME = *WSO2::WSF::Cc::WSF_CONF_WSFC_HOME;
*AXIS2_HTTP_GET = *WSO2::WSF::Cc::AXIS2_HTTP_GET;
*AXIS2_HTTP_METHOD = *WSO2::WSF::Cc::AXIS2_HTTP_METHOD;
*AXIS2_VALUE_TRUE = *WSO2::WSF::Cc::AXIS2_VALUE_TRUE;
*AXIS2_TRUE = *WSO2::WSF::Cc::AXIS2_TRUE;
*AXIS2_FALSE = *WSO2::WSF::Cc::AXIS2_FALSE;
*AXIS2_WSA_NAMESPACE_SUBMISSION = *WSO2::WSF::Cc::AXIS2_WSA_NAMESPACE_SUBMISSION;
*AXIS2_WSA_VERSION = *WSO2::WSF::Cc::AXIS2_WSA_VERSION;
*AXIOM_SOAP_STYLE_RPC_ENCODED = *WSO2::WSF::Cc::AXIOM_SOAP_STYLE_RPC_ENCODED;
*AXIOM_SOAP_STYLE_DOC_LITERAL_WRAPPED = *WSO2::WSF::Cc::AXIOM_SOAP_STYLE_DOC_LITERAL_WRAPPED;
*AXIS2_SCOPE = *WSO2::WSF::Cc::AXIS2_SCOPE;
*AXIS2_APPLICATION_SCOPE = *WSO2::WSF::Cc::AXIS2_APPLICATION_SCOPE;
*AXIS2_SESSION_SCOPE = *WSO2::WSF::Cc::AXIS2_SESSION_SCOPE;
*AXIS2_MESSAGE_SCOPE = *WSO2::WSF::Cc::AXIS2_MESSAGE_SCOPE;
*AXIS2_PHASE_SERVICE = *WSO2::WSF::Cc::AXIS2_PHASE_SERVICE;
*AXIS2_PHASE_TRANSPORT = *WSO2::WSF::Cc::AXIS2_PHASE_TRANSPORT;
*AXIS2_PHASE_GLOBAL = *WSO2::WSF::Cc::AXIS2_PHASE_GLOBAL;
*AXIS2_SESSION_CONTEXT_PROPERTY = *WSO2::WSF::Cc::AXIS2_SESSION_CONTEXT_PROPERTY;
*AXIS2_TRANSPORT_HTTP = *WSO2::WSF::Cc::AXIS2_TRANSPORT_HTTP;
*AXIS2_TRANSPORT_SMTP = *WSO2::WSF::Cc::AXIS2_TRANSPORT_SMTP;
*AXIS2_TRANSPORT_TCP = *WSO2::WSF::Cc::AXIS2_TRANSPORT_TCP;
*AXIS2_TRANSPORT_XMPP = *WSO2::WSF::Cc::AXIS2_TRANSPORT_XMPP;
*AXIS2_TRANSPORT_HTTPS = *WSO2::WSF::Cc::AXIS2_TRANSPORT_HTTPS;
*AXIS2_TRANSPORT_ENUM_HTTP = *WSO2::WSF::Cc::AXIS2_TRANSPORT_ENUM_HTTP;
*AXIS2_TRANSPORT_ENUM_SMTP = *WSO2::WSF::Cc::AXIS2_TRANSPORT_ENUM_SMTP;
*AXIS2_TRANSPORT_ENUM_TCP = *WSO2::WSF::Cc::AXIS2_TRANSPORT_ENUM_TCP;
*AXIS2_TRANSPORT_ENUM_XMPP = *WSO2::WSF::Cc::AXIS2_TRANSPORT_ENUM_XMPP;
*AXIS2_TRANSPORT_ENUM_HTTPS = *WSO2::WSF::Cc::AXIS2_TRANSPORT_ENUM_HTTPS;
*AXIS2_TRANSPORT_ENUM_MAX = *WSO2::WSF::Cc::AXIS2_TRANSPORT_ENUM_MAX;
*AXIS2_REQUEST_URL_PREFIX = *WSO2::WSF::Cc::AXIS2_REQUEST_URL_PREFIX;
*AXIS2_LISTSERVICES = *WSO2::WSF::Cc::AXIS2_LISTSERVICES;
*AXIS2_LIST_SERVICE_FOR_MODULE_ENGAMNET = *WSO2::WSF::Cc::AXIS2_LIST_SERVICE_FOR_MODULE_ENGAMNET;
*AXIS2_ADMIN_LISTSERVICES = *WSO2::WSF::Cc::AXIS2_ADMIN_LISTSERVICES;
*AXIS2_LIST_MODULES = *WSO2::WSF::Cc::AXIS2_LIST_MODULES;
*AXIS2_LIST_GLOABLLY_ENGAGED_MODULES = *WSO2::WSF::Cc::AXIS2_LIST_GLOABLLY_ENGAGED_MODULES;
*AXIS2_LIST_PHASES = *WSO2::WSF::Cc::AXIS2_LIST_PHASES;
*AXIS2_ENGAGE_GLOBAL_MODULE = *WSO2::WSF::Cc::AXIS2_ENGAGE_GLOBAL_MODULE;
*AXIS2_ENGAGE_MODULE_TO_SERVICE = *WSO2::WSF::Cc::AXIS2_ENGAGE_MODULE_TO_SERVICE;
*AXIS2_ENGAGE_MODULE_TO_SERVICE_GROUP = *WSO2::WSF::Cc::AXIS2_ENGAGE_MODULE_TO_SERVICE_GROUP;
*AXIS2_ADMIN_LOGIN = *WSO2::WSF::Cc::AXIS2_ADMIN_LOGIN;
*AXIS2_LIST_CONTEXTS = *WSO2::WSF::Cc::AXIS2_LIST_CONTEXTS;
*AXIS2_LOGOUT = *WSO2::WSF::Cc::AXIS2_LOGOUT;
*AXIS2_VIEW_GLOBAL_HANDLERS = *WSO2::WSF::Cc::AXIS2_VIEW_GLOBAL_HANDLERS;
*AXIS2_SELECT_SERVICE = *WSO2::WSF::Cc::AXIS2_SELECT_SERVICE;
*AXIS2_EDIR_SERVICE_PARA = *WSO2::WSF::Cc::AXIS2_EDIR_SERVICE_PARA;
*AXIS2_SELECT_SERVICE_FOR_PARA_EDIT = *WSO2::WSF::Cc::AXIS2_SELECT_SERVICE_FOR_PARA_EDIT;
*AXIS2_VIEW_SERVICE_HANDLERS = *WSO2::WSF::Cc::AXIS2_VIEW_SERVICE_HANDLERS;
*AXIS2_LIST_SERVIC_GROUPS = *WSO2::WSF::Cc::AXIS2_LIST_SERVIC_GROUPS;
*AXIS2_SERVICE_MAP = *WSO2::WSF::Cc::AXIS2_SERVICE_MAP;
*AXIS2_SERVICE_GROUP_MAP = *WSO2::WSF::Cc::AXIS2_SERVICE_GROUP_MAP;
*AXIS2_CONFIG_CONTEXT = *WSO2::WSF::Cc::AXIS2_CONFIG_CONTEXT;
*AXIS2_ACTION_MAPPING = *WSO2::WSF::Cc::AXIS2_ACTION_MAPPING;
*AXIS2_OUTPUT_ACTION_MAPPING = *WSO2::WSF::Cc::AXIS2_OUTPUT_ACTION_MAPPING;
*AXI2_FAULT_ACTION_MAPPING = *WSO2::WSF::Cc::AXI2_FAULT_ACTION_MAPPING;
*AXIS2_SERVICE = *WSO2::WSF::Cc::AXIS2_SERVICE;
*AXIS2_OPEARTION_MAP = *WSO2::WSF::Cc::AXIS2_OPEARTION_MAP;
*AXIS2_MODULE_ADDRESSING = *WSO2::WSF::Cc::AXIS2_MODULE_ADDRESSING;
*AXIS2_MODULE_SANDESHA2 = *WSO2::WSF::Cc::AXIS2_MODULE_SANDESHA2;
*AXIS2_USER_NAME = *WSO2::WSF::Cc::AXIS2_USER_NAME;
*AXIS2_PASSWORD = *WSO2::WSF::Cc::AXIS2_PASSWORD;
*AXIS2_SINGLE_SERVICE = *WSO2::WSF::Cc::AXIS2_SINGLE_SERVICE;
*AXIS2_WSDL_CONTENT = *WSO2::WSF::Cc::AXIS2_WSDL_CONTENT;
*AXIS2_REQUEST_WSDL = *WSO2::WSF::Cc::AXIS2_REQUEST_WSDL;
*AXIS2_STYLE_RPC = *WSO2::WSF::Cc::AXIS2_STYLE_RPC;
*AXIS2_STYLE_DOC = *WSO2::WSF::Cc::AXIS2_STYLE_DOC;
*AXIS2_STYLE_MSG = *WSO2::WSF::Cc::AXIS2_STYLE_MSG;
*AXIS2_WSDL_MESSAGE_LABEL_IN = *WSO2::WSF::Cc::AXIS2_WSDL_MESSAGE_LABEL_IN;
*AXIS2_WSDL_MESSAGE_LABEL_OUT = *WSO2::WSF::Cc::AXIS2_WSDL_MESSAGE_LABEL_OUT;
*AXIS2_WSDL_MESSAGE_LABEL_MAX = *WSO2::WSF::Cc::AXIS2_WSDL_MESSAGE_LABEL_MAX;
*AXIS2_MEP_URI_IN_ONLY = *WSO2::WSF::Cc::AXIS2_MEP_URI_IN_ONLY;
*AXIS2_MEP_CONSTANT_IN_ONLY = *WSO2::WSF::Cc::AXIS2_MEP_CONSTANT_IN_ONLY;
*AXIS2_MEP_URI_ROBUST_IN_ONLY = *WSO2::WSF::Cc::AXIS2_MEP_URI_ROBUST_IN_ONLY;
*AXIS2_MEP_CONSTANT_ROBUST_IN_ONLY = *WSO2::WSF::Cc::AXIS2_MEP_CONSTANT_ROBUST_IN_ONLY;
*AXIS2_MEP_URI_IN_OUT = *WSO2::WSF::Cc::AXIS2_MEP_URI_IN_OUT;
*AXIS2_MEP_CONSTANT_IN_OUT = *WSO2::WSF::Cc::AXIS2_MEP_CONSTANT_IN_OUT;
*AXIS2_MEP_URI_IN_OPTIONAL_OUT = *WSO2::WSF::Cc::AXIS2_MEP_URI_IN_OPTIONAL_OUT;
*AXIS2_MEP_CONSTANT_IN_OPTIONAL_OUT = *WSO2::WSF::Cc::AXIS2_MEP_CONSTANT_IN_OPTIONAL_OUT;
*AXIS2_MEP_URI_OUT_ONLY = *WSO2::WSF::Cc::AXIS2_MEP_URI_OUT_ONLY;
*AXIS2_MEP_CONSTANT_OUT_ONLY = *WSO2::WSF::Cc::AXIS2_MEP_CONSTANT_OUT_ONLY;
*AXIS2_MEP_URI_ROBUST_OUT_ONLY = *WSO2::WSF::Cc::AXIS2_MEP_URI_ROBUST_OUT_ONLY;
*AXIS2_MEP_CONSTANT_ROBUST_OUT_ONLY = *WSO2::WSF::Cc::AXIS2_MEP_CONSTANT_ROBUST_OUT_ONLY;
*AXIS2_MEP_URI_OUT_IN = *WSO2::WSF::Cc::AXIS2_MEP_URI_OUT_IN;
*AXIS2_MEP_CONSTANT_OUT_IN = *WSO2::WSF::Cc::AXIS2_MEP_CONSTANT_OUT_IN;
*AXIS2_MEP_URI_OUT_OPTIONAL_IN = *WSO2::WSF::Cc::AXIS2_MEP_URI_OUT_OPTIONAL_IN;
*AXIS2_MEP_CONSTANT_OUT_OPTIONAL_IN = *WSO2::WSF::Cc::AXIS2_MEP_CONSTANT_OUT_OPTIONAL_IN;
*AXIS2_MEP_CONSTANT_INVALID = *WSO2::WSF::Cc::AXIS2_MEP_CONSTANT_INVALID;
*AXIS2_WSDL_MESSAGE_DIRECTION_IN = *WSO2::WSF::Cc::AXIS2_WSDL_MESSAGE_DIRECTION_IN;
*AXIS2_WSDL_MESSAGE_DIRECTION_OUT = *WSO2::WSF::Cc::AXIS2_WSDL_MESSAGE_DIRECTION_OUT;
*AXIS2_LOGGED = *WSO2::WSF::Cc::AXIS2_LOGGED;
*AXIS2_ENABLE_REST = *WSO2::WSF::Cc::AXIS2_ENABLE_REST;
*AXIS2_ENABLE_REST_THROUGH_GET = *WSO2::WSF::Cc::AXIS2_ENABLE_REST_THROUGH_GET;
*AXIS2_ENABLE_MTOM = *WSO2::WSF::Cc::AXIS2_ENABLE_MTOM;
*AXIS2_ATTACHMENT_TEMP_DIR = *WSO2::WSF::Cc::AXIS2_ATTACHMENT_TEMP_DIR;
*AXIS2_CACHE_ATTACHMENTS = *WSO2::WSF::Cc::AXIS2_CACHE_ATTACHMENTS;
*AXIS2_FILE_SIZE_THRESHOLD = *WSO2::WSF::Cc::AXIS2_FILE_SIZE_THRESHOLD;
*AXIS2_PERSIST_OP_CTX = *WSO2::WSF::Cc::AXIS2_PERSIST_OP_CTX;
*AXIS2_VALUE_FALSE = *WSO2::WSF::Cc::AXIS2_VALUE_FALSE;
*AXIS2_CONTAINER_MANAGED = *WSO2::WSF::Cc::AXIS2_CONTAINER_MANAGED;
*AXIS2_RESPONSE_WRITTEN = *WSO2::WSF::Cc::AXIS2_RESPONSE_WRITTEN;
*AXIS2_TESTING_PATH = *WSO2::WSF::Cc::AXIS2_TESTING_PATH;
*AXIS2_TESTING_REPOSITORY = *WSO2::WSF::Cc::AXIS2_TESTING_REPOSITORY;
*AXIS2_LOAD_SVC_STARTUP = *WSO2::WSF::Cc::AXIS2_LOAD_SVC_STARTUP;
*AXIS2_GET_PARAMETER_OP = *WSO2::WSF::Cc::AXIS2_GET_PARAMETER_OP;
*AXIS2_GET_PARAMETER_URL = *WSO2::WSF::Cc::AXIS2_GET_PARAMETER_URL;
*AXIS2_NAMESPACE_PREFIX = *WSO2::WSF::Cc::AXIS2_NAMESPACE_PREFIX;
*AXIS2_NAMESPACE_URI = *WSO2::WSF::Cc::AXIS2_NAMESPACE_URI;
*AXIS2_SVC_GRP_ID = *WSO2::WSF::Cc::AXIS2_SVC_GRP_ID;
*AXIS2_RESPONSE_SOAP_ENVELOPE = *WSO2::WSF::Cc::AXIS2_RESPONSE_SOAP_ENVELOPE;
*AXIS2_HANDLER_ALREADY_VISITED = *WSO2::WSF::Cc::AXIS2_HANDLER_ALREADY_VISITED;
*WSF_POLICY = *WSO2::WSF::Cc::WSF_POLICY;
*WSF_IN_POLICY = *WSO2::WSF::Cc::WSF_IN_POLICY;
*WSF_OUT_POLICY = *WSO2::WSF::Cc::WSF_OUT_POLICY;
*WSF_SIGN = *WSO2::WSF::Cc::WSF_SIGN;
*WSF_ENCRYPT = *WSO2::WSF::Cc::WSF_ENCRYPT;
*WSF_ALGORITHM = *WSO2::WSF::Cc::WSF_ALGORITHM;
*WSF_LAYOUT = *WSO2::WSF::Cc::WSF_LAYOUT;
*WSF_TIMESTAMP = *WSO2::WSF::Cc::WSF_TIMESTAMP;
*WSF_PROTECTION_ORDER = *WSO2::WSF::Cc::WSF_PROTECTION_ORDER;
*WSF_UT = *WSO2::WSF::Cc::WSF_UT;
*WSF_TOKEN_REFERENCE = *WSO2::WSF::Cc::WSF_TOKEN_REFERENCE;
*WSF_ENCRYPT_SIGNATURE = *WSO2::WSF::Cc::WSF_ENCRYPT_SIGNATURE;
*WSF_DEFAULT_TOKEN_VAL = *WSO2::WSF::Cc::WSF_DEFAULT_TOKEN_VAL;
*WSF_X509_TOKEN_VAL = *WSO2::WSF::Cc::WSF_X509_TOKEN_VAL;
*WSF_INITIATOR_VAL = *WSO2::WSF::Cc::WSF_INITIATOR_VAL;
*WSF_INCLUDE_TOKEN_URI = *WSO2::WSF::Cc::WSF_INCLUDE_TOKEN_URI;
*WSF_INCLUDE_TOKEN = *WSO2::WSF::Cc::WSF_INCLUDE_TOKEN;
*WSF_RECIPIENT_TOKEN = *WSO2::WSF::Cc::WSF_RECIPIENT_TOKEN;
*WSF_USERNAMETOKEN = *WSO2::WSF::Cc::WSF_USERNAMETOKEN;
*WSF_SIGNSUPPORTING_TOKEN = *WSO2::WSF::Cc::WSF_SIGNSUPPORTING_TOKEN;
*WSF_ALGO_SUITE = *WSO2::WSF::Cc::WSF_ALGO_SUITE;
*WSF_ONLY_SIGN_HEADER_AND_BODY = *WSO2::WSF::Cc::WSF_ONLY_SIGN_HEADER_AND_BODY;
*WSF_ENCRYPTPARTS = *WSO2::WSF::Cc::WSF_ENCRYPTPARTS;
*WSF_BODY = *WSO2::WSF::Cc::WSF_BODY;
*WSF_LAYOUT_VAL = *WSO2::WSF::Cc::WSF_LAYOUT_VAL;
*WSF_STRICT = *WSO2::WSF::Cc::WSF_STRICT;
*WSF_WSS10 = *WSO2::WSF::Cc::WSF_WSS10;
*WSF_USER = *WSO2::WSF::Cc::WSF_USER;
*WSF_CERTIFICATE = *WSO2::WSF::Cc::WSF_CERTIFICATE;
*WSF_PASSWORD_TYPE = *WSO2::WSF::Cc::WSF_PASSWORD_TYPE;
*WSF_PASSWORD = *WSO2::WSF::Cc::WSF_PASSWORD;
*WSF_PRIVATE_KEY = *WSO2::WSF::Cc::WSF_PRIVATE_KEY;
*WSF_TTL = *WSO2::WSF::Cc::WSF_TTL;
*WSF_RECEIVER_CERTIFICATE = *WSO2::WSF::Cc::WSF_RECEIVER_CERTIFICATE;
*WSF_DIGEST = *WSO2::WSF::Cc::WSF_DIGEST;
*WSF_PLAINTEXT = *WSO2::WSF::Cc::WSF_PLAINTEXT;
*WSF_PASSWORD_CALL_BACK = *WSO2::WSF::Cc::WSF_PASSWORD_CALL_BACK;
*BASIC256 = *WSO2::WSF::Cc::BASIC256;
*BASIC192 = *WSO2::WSF::Cc::BASIC192;
*BASIC128 = *WSO2::WSF::Cc::BASIC128;
*TRIPLEDES = *WSO2::WSF::Cc::TRIPLEDES;
*BASIC256_RSA15 = *WSO2::WSF::Cc::BASIC256_RSA15;
*BASIC192_RSA15 = *WSO2::WSF::Cc::BASIC192_RSA15;
*BASIC128_RSA15 = *WSO2::WSF::Cc::BASIC128_RSA15;
*TRIPLEDES_RSA15 = *WSO2::WSF::Cc::TRIPLEDES_RSA15;
*ISSUER_SERIAL = *WSO2::WSF::Cc::ISSUER_SERIAL;
*KEYIDENTIFIER = *WSO2::WSF::Cc::KEYIDENTIFIER;
*EMBEDDEDTOKEN = *WSO2::WSF::Cc::EMBEDDEDTOKEN;
*THUMBPRINT = *WSO2::WSF::Cc::THUMBPRINT;
*DIRECT = *WSO2::WSF::Cc::DIRECT;
*ISSUER_SERIAL_VAL = *WSO2::WSF::Cc::ISSUER_SERIAL_VAL;
*KEYIDENTIFIER_VAL = *WSO2::WSF::Cc::KEYIDENTIFIER_VAL;
*EMBEDDEDTOKEN_VAL = *WSO2::WSF::Cc::EMBEDDEDTOKEN_VAL;
*THUMBPRINT_VAL = *WSO2::WSF::Cc::THUMBPRINT_VAL;
*SIGN_BEFORE = *WSO2::WSF::Cc::SIGN_BEFORE;
*ENCRYPT_BEFORE = *WSO2::WSF::Cc::ENCRYPT_BEFORE;
*RP_REQUIRE_KEY_IDENTIFIRE_REFERENCE = *WSO2::WSF::Cc::RP_REQUIRE_KEY_IDENTIFIRE_REFERENCE;
*RP_REQUIRE_ISSUER_SERIAL_REFERENCE = *WSO2::WSF::Cc::RP_REQUIRE_ISSUER_SERIAL_REFERENCE;
*RP_REQUIRE_EMBEDDED_TOKEN_REFERENCE = *WSO2::WSF::Cc::RP_REQUIRE_EMBEDDED_TOKEN_REFERENCE;
*RP_REQUIRE_THUMBPRINT_REFERENCE = *WSO2::WSF::Cc::RP_REQUIRE_THUMBPRINT_REFERENCE;
*RP_REQUIRE_DERIVED_KEYS = *WSO2::WSF::Cc::RP_REQUIRE_DERIVED_KEYS;
*WSF_RAMPART_CONFIGURATION = *WSO2::WSF::Cc::WSF_RAMPART_CONFIGURATION;
*WSF_ELEMENT_LN_SOAP12_FAULT_CODE = *WSO2::WSF::Cc::WSF_ELEMENT_LN_SOAP12_FAULT_CODE;
*WSF_ELEMENT_LN_SOAP12_FAULT_REASON = *WSO2::WSF::Cc::WSF_ELEMENT_LN_SOAP12_FAULT_REASON;
*WSF_ELEMENT_LN_SOAP12_FAULT_DETAIL = *WSO2::WSF::Cc::WSF_ELEMENT_LN_SOAP12_FAULT_DETAIL;
*WSF_ELEMENT_LN_SOAP12_FAULT_ROLE = *WSO2::WSF::Cc::WSF_ELEMENT_LN_SOAP12_FAULT_ROLE;
*WSF_ELEMENT_LN_SOAP11_FAULT_CODE = *WSO2::WSF::Cc::WSF_ELEMENT_LN_SOAP11_FAULT_CODE;
*WSF_ELEMENT_LN_SOAP11_FAULT_REASON = *WSO2::WSF::Cc::WSF_ELEMENT_LN_SOAP11_FAULT_REASON;
*WSF_ELEMENT_LN_SOAP11_FAULT_DETAIL = *WSO2::WSF::Cc::WSF_ELEMENT_LN_SOAP11_FAULT_DETAIL;
*WSF_ELEMENT_LN_SOAP11_FAULT_ROLE = *WSO2::WSF::Cc::WSF_ELEMENT_LN_SOAP11_FAULT_ROLE;
*AXIS2_MODULE_RAMPART = *WSO2::WSF::Cc::AXIS2_MODULE_RAMPART;
1;
